@@ -93,7 +93,11 @@ def upload(destination, file, progress_bar=False, filename='features_backup.rcdb
 
 @tenacity.retry(stop=tenacity.stop_after_attempt(3))
 def download(source, destination=None, progress_bar=False):
+    r = requests.get(source, stream=True, allow_redirects=True)
+    r.raise_for_status()
+
     is_file = False
+
     if destination is None:
         fp = six.BytesIO()
     elif hasattr(destination, 'write') and hasattr(destination, 'read'):
@@ -103,7 +107,6 @@ def download(source, destination=None, progress_bar=False):
         fp = open(destination, 'wb')
         is_file = True
 
-    r = requests.get(source, stream=True)
     chunk, chunk_size = 1, 1024
 
     if progress_bar:
