@@ -17,12 +17,12 @@ from rebotics_sdk.advanced import remote_loaders
 from rebotics_sdk.cli.common import shell, configure, roles, set_token
 from .renderers import format_full_table
 from .utils import ReboticsCLIContext, app_dir, pass_rebotics_context, read_saved_role, process_role
-from ..advanced.flows import FileUploadError, download_vrcdb_file, ReboticsClassificationDatabase
+from ..advanced.flows import FileUploadError
 from ..advanced.packers import ClassificationDatabasePacker, ClassificationDatabaseException, \
-    DuplicateFeatureVectorsException, VirtualClassificationDatabasePacker
+    DuplicateFeatureVectorsException
 from ..constants import RCDB
 from ..providers import AdminProvider, RetailerProvider
-from ..utils import Timer, uri_validator, download_and_return_id, get_filename_from_url
+from ..utils import uri_validator, download_and_return_id, get_filename_from_url
 
 
 @click.group()
@@ -347,89 +347,6 @@ def rcdb_group():
     click.echo("RCDB in rebotics admin is deprecated and will be removed in version 0.13.0")
 
 
-@rcdb_group.command()
-@click.option('-r', '--retailer', help="Retailer codename", prompt=True)
-@click.option('-m', '--model', help="Model codename", prompt=True)
-@click.option('-c', '--concurrency', type=int, default=4)
-@click.argument('target', type=click.Path(exists=False, file_okay=False, dir_okay=True), default='.')
-@pass_rebotics_context
-def backup_and_download_rcdb(ctx, retailer, model, target, concurrency):
-    """
-    CLI command to trigger the upload
-    """
-    rcdb = ReboticsClassificationDatabase(ctx.provider)
-    # a flow that will request to do a backup of the retailer + model from the Admin
-    res = rcdb.create(retailer, model)
-    id_ = res['id']
-
-    # next flow wait for it to be processed calling the function to be done or not every N minutes
-    with Timer() as t:
-        while True:
-            res = rcdb.get(id_)
-            if res['status'] == RCDB.EXPORT_DONE:
-                file_url = res['backup']
-                break
-            if res['status'] == RCDB.EXPORT_ERROR:
-                raise click.ClickException("Creating and RCDB file failed")
-            sleep(5)
-
-    click.echo("Elapsed time: {}".format(t.elapsed_secs))
-
-    # flow that will download the rcdb file
-    file_io = remote_loaders.download(file_url, progress_bar=True)
-
-    # next flow that will unpack rcdb into target directory
-    target = pathlib.Path(target) / "rcdb_{}_{}_{}".format(retailer, model, id_)
-
-    packer = VirtualClassificationDatabasePacker(source=file_io)
-    download_vrcdb_file(packer, target, concurrency=concurrency)
-
-
-@rcdb_group.command(name='virtual-download')
-@click.option('-c', '--concurrency', type=int, default=4)
-@click.argument('target', type=click.Path(exists=False, file_okay=False, dir_okay=True), default='.')
-@click.argument('backup_ids', type=click.INT, nargs=-1)
-@pass_rebotics_context
-def download_rcdb(ctx, backup_ids, target, concurrency):
-    """
-    Download rcdb by id
-    :param ctx:
-    :param backup_ids:
-    :param target:
-    :param concurrency:
-    :return:
-    """
-    rcdb = ReboticsClassificationDatabase(ctx.provider)
-    target = pathlib.Path(target)
-
-    for backup_id in backup_ids:
-        res = rcdb.get(backup_id)
-
-        file_url = res['backup']
-        retailer = res['retailer']
-        model = res['facenet_model']
-
-        # flow that will download the rcdb file
-        file_io = remote_loaders.download(file_url, progress_bar=True)
-
-        # next flow that will unpack rcdb into target directory
-        download_folder = target / "rcdb_{}_{}_{}".format(retailer, model, backup_id)
-
-        packer = VirtualClassificationDatabasePacker(source=file_io)
-        download_vrcdb_file(packer, download_folder, concurrency=concurrency)
-
-
-@rcdb_group.command('virtual-unpack')
-@click.option('-c', '--concurrency', type=int, default=4)
-@click.argument('backup', type=click.Path(exists=True, file_okay=True, dir_okay=False))
-@click.argument('target', type=click.Path(exists=False, file_okay=False, dir_okay=True), default='.')
-@pass_rebotics_context
-def unpack_rcdb(backup, target, concurrency):
-    # TODO: check by filename and extension
-    packer = VirtualClassificationDatabasePacker(source=backup)
-    download_vrcdb_file(packer, target, concurrency=concurrency)
-
-
 @rcdb_group.command(name="previews-fs")
 @click.argument("argument", type=click.STRING)
 @click.option('-o', "--output", type=click.Path(exists=True, dir_okay=True, file_okay=False), default=".")
@@ -479,9 +396,9 @@ def rcdb_previews_fs(ctx, argument, output, concurrency):
 
     with Pool(concurrency) as pool:
         for _ in tqdm.tqdm(
-                pool.imap_unordered(partial(download_and_return_id, output=output), definition),
-                desc=f"Downloading images to {str(output)}",
-                total=len(definition),
+            pool.imap_unordered(partial(download_and_return_id, output=output), definition),
+            desc=f"Downloading images to {str(output)}",
+            total=len(definition),
         ):
             pass
         pool.close()
