@@ -15,6 +15,7 @@ from ..advanced import remote_loaders
 from ..providers import DatasetProvider, ProviderHTTPClientException
 from ..providers.utils import get_id_list_from_ranges
 from ..utils import download_file, mkdir_p, get_filename_from_url
+from ..constants import DownloadImagesFormat
 
 
 @click.group()
@@ -170,33 +171,39 @@ def download_ref_backup(ctx, retailer, facenet, output):
         shutil.copyfileobj(raw, out_file)
 
 
-def task_download_and_set_training_data(item_id, target, ctx):
+def task_download_and_set_training_data(item_id, target, format, ctx):
     try:
         response = ctx.provider.get_detection_image_by_id(item_id)
     except:
         click.echo("Failed to find image with id={}".format(item_id))
         return
     # download images and download this json
-    image_url = response['image']
-    json_file = target / "{}.json".format(item_id)
-    image_file = target / "{}.{ext}".format(
-        item_id,
-        ext=get_filename_from_url(image_url).split(".")[-1]
-    )
-    try:
-        remote_loaders.download(image_url, str(image_file))
-    except:
-        click.echo("{} failed to download image from {}".format(item_id, image_url))
-    with open(str(json_file), 'w') as fio:
-        json.dump(response, fio, indent=4)
+    if format in (DownloadImagesFormat.FULL, DownloadImagesFormat.IMAGES):
+        image_url = response['image']
+        image_file = target / "{}.{ext}".format(
+            item_id,
+            ext=get_filename_from_url(image_url).split(".")[-1]
+        )
+        try:
+            remote_loaders.download(image_url, str(image_file))
+        except:
+            click.echo("{} failed to download image from {}".format(item_id, image_url))
+    if format in (DownloadImagesFormat.FULL, DownloadImagesFormat.ANNOTATIONS):
+        json_file = target / "{}.json".format(item_id)
+        with open(str(json_file), 'w') as fio:
+            json.dump(response, fio, indent=4)
 
 
 @api.command()
 @click.argument("image_ids", type=click.STRING)
 @click.option('-t', '--target', type=click.Path(), default='.')
 @click.option('-c', '--concurrency', type=int, default=4)
+@click.option('-f', '--format',
+              type=click.Choice(DownloadImagesFormat.OPTIONS, case_sensitive=False),
+              default=DownloadImagesFormat.FULL,)
 @pass_rebotics_context
-def download_images(ctx, image_ids, target, concurrency):
+def download_images(ctx, image_ids, target, concurrency, format):
+    """Download images and/or annotations json."""
     # parse image_ids as range or as a ids
     id_list = get_id_list_from_ranges(image_ids)
     if ctx.verbose:
@@ -209,7 +216,10 @@ def download_images(ctx, image_ids, target, concurrency):
 
     with Pool(min(len(id_list), concurrency)) as pool:
         pool.map(
-            partial(task_download_and_set_training_data, target=pathlib.Path(target), ctx=ctx),
+            partial(task_download_and_set_training_data,
+                    target=pathlib.Path(target),
+                    format=format,
+                    ctx=ctx,),
             id_list
         )
     pool.join()
