@@ -683,7 +683,7 @@ def processing_action_copy(ctx, store):
         result = ctx.provider.create_processing_action(
             store_id,
             files=inputs_id,
-            input_type=action['input_type'],
+            input_type=action.get('input_type', 'image'),
         )
         click.echo('Successfully created processing action')
         format_processing_action_output([result, ], ctx.format)
