@@ -2,8 +2,8 @@ from rest_framework import status
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-from rebotics_sdk.hook import signals
 from rebotics_sdk.hook.serializers import WebhookDataSerializer
+from rebotics_sdk.hook import signals
 
 
 class WebhookHandlerViewSet(APIView):
@@ -14,12 +14,11 @@ class WebhookHandlerViewSet(APIView):
         serializer = WebhookDataSerializer(data=request.data)
         serializer.is_valid(raise_exception=True)
 
-        emitter = signals.emitter_factory(
-            retailer_code,
-            serializer.validated_data['component'],
-            serializer.validated_data['status'],
-            serializer.validated_data['body'],
-            request)
+        emitter = signals.SignalEmitter(
+            retailer=retailer_code,
+            event=serializer.validated_data['event'],
+            payload=serializer.validated_data['payload'],
+        )
         emitter.emit()
 
         return Response(status=status.HTTP_202_ACCEPTED)
