@@ -1,5 +1,5 @@
 from .base import *  # NOQA
 from .admin import AdminProvider  # NOQA
 from .dataset import DatasetProvider  # NOQA
-from .facenet import FacenetProvider  # NOQA
 from .retailer import RetailerProvider  # NOQA
+from .fvm import FVMProvider # NOQA
