@@ -146,3 +146,16 @@ class AdminProvider(ReboticsBaseProvider):
     @remote_service('/core/core-callback/{id}/')
     def get_core_callback_data(self, pk):
         return self.session.get(id=pk)
+
+    @remote_service('/core-test/cases/')
+    def create_core_test_case(self, yaml_template, title, group, description):
+        return self.session.post(json={
+            'title': title,
+            'group': group,
+            'description': description,
+            'yaml_template': yaml_template,
+        })
+
+    @remote_service('/core-test/cases/{id}/')
+    def get_core_test_case(self, id_):
+        return self.session.get(id=id_)
