@@ -322,6 +322,35 @@ class PageResult(dict):
     def pdf_download_url(self):
         return self.json_data.get('pdf_url')
 
+    @property
+    def next_page(self):
+        return self.json_data['next']
+
+
+class APIPageIterator:
+    """
+    Basic usage:
+        iterator = APIPageIterator(provider.get_products_list, 1)
+        for data in iterator:
+            # do whatever with the data
+            pass
+    """
+    def __init__(self, method, initial_page=1, **filter_params):
+        self.method = method
+        self.filter_params = filter_params  # page size can be passed as an optional value
+        self.page = initial_page
+
+    def __iter__(self):
+        while True:
+            page_result = self.method(page=self.page, **self.filter_params)
+
+            yield from page_result
+
+            if not page_result.next_page:
+                break
+
+            self.page += 1
+
 
 def required_model_params(params=None):
     if params is None:
